@@ -1,7 +1,7 @@
 /*
  * libbrlapi - A library providing access to braille terminals for applications.
  *
- * Copyright (C) 2002-2014 by
+ * Copyright (C) 2002-2018 by
  *   Samuel Thibault <Samuel.Thibault@ens-lyon.org>
  *   Sébastien Hinderer <Sebastien.Hinderer@ens-lyon.org>
  *
@@ -12,7 +12,7 @@
  * Foundation; either version 2.1 of the License, or (at your option) any
  * later version. Please see the file LICENSE-LGPL for details.
  *
- * Web Page: http://mielke.cc/brltty/
+ * Web Page: http://brltty.com/
  *
  * This software is maintained by Dave Mielke <dave@mielke.cc>.
  */
@@ -56,7 +56,7 @@ extern "C" {
 #define BRLAPI_KEY_CMD_TOP_LEFT (BRLAPI_KEY_CMD(0) + 11)
 /** go to beginning of bottom line */
 #define BRLAPI_KEY_CMD_BOT_LEFT (BRLAPI_KEY_CMD(0) + 12)
-/** go up to last line of previous paragraph */
+/** go up to first line of paragraph */
 #define BRLAPI_KEY_CMD_PRPGRPH (BRLAPI_KEY_CMD(0) + 13)
 /** go down to first line of next paragraph */
 #define BRLAPI_KEY_CMD_NXPGRPH (BRLAPI_KEY_CMD(0) + 14)
@@ -72,27 +72,27 @@ extern "C" {
 #define BRLAPI_KEY_CMD_CHRLT (BRLAPI_KEY_CMD(0) + 19)
 /** go right one character */
 #define BRLAPI_KEY_CMD_CHRRT (BRLAPI_KEY_CMD(0) + 20)
-/** go left half a window */
+/** go left half a braille window */
 #define BRLAPI_KEY_CMD_HWINLT (BRLAPI_KEY_CMD(0) + 21)
-/** go right half a window */
+/** go right half a braille window */
 #define BRLAPI_KEY_CMD_HWINRT (BRLAPI_KEY_CMD(0) + 22)
-/** go left one window */
+/** go backward one braille window */
 #define BRLAPI_KEY_CMD_FWINLT (BRLAPI_KEY_CMD(0) + 23)
-/** go right one window */
+/** go forward one braille window */
 #define BRLAPI_KEY_CMD_FWINRT (BRLAPI_KEY_CMD(0) + 24)
-/** go left to nearest non-blank window */
+/** go backward skipping blank braille windows */
 #define BRLAPI_KEY_CMD_FWINLTSKIP (BRLAPI_KEY_CMD(0) + 25)
-/** go right to nearest non-blank window */
+/** go forward skipping blank braille windows */
 #define BRLAPI_KEY_CMD_FWINRTSKIP (BRLAPI_KEY_CMD(0) + 26)
 /** go to beginning of line */
 #define BRLAPI_KEY_CMD_LNBEG (BRLAPI_KEY_CMD(0) + 27)
 /** go to end of line */
 #define BRLAPI_KEY_CMD_LNEND (BRLAPI_KEY_CMD(0) + 28)
-/** go to cursor */
+/** go to screen cursor */
 #define BRLAPI_KEY_CMD_HOME (BRLAPI_KEY_CMD(0) + 29)
 /** go back after cursor tracking */
 #define BRLAPI_KEY_CMD_BACK (BRLAPI_KEY_CMD(0) + 30)
-/** go to cursor or go back after cursor tracking */
+/** go to screen cursor or go back after cursor tracking */
 #define BRLAPI_KEY_CMD_RETURN (BRLAPI_KEY_CMD(0) + 31)
 /** set screen image frozen/unfrozen */
 #define BRLAPI_KEY_CMD_FREEZE (BRLAPI_KEY_CMD(0) + 32)
@@ -100,21 +100,21 @@ extern "C" {
 #define BRLAPI_KEY_CMD_DISPMD (BRLAPI_KEY_CMD(0) + 33)
 /** set text style 6-dot/8-dot */
 #define BRLAPI_KEY_CMD_SIXDOTS (BRLAPI_KEY_CMD(0) + 34)
-/** set sliding window on/off */
+/** set sliding braille window on/off */
 #define BRLAPI_KEY_CMD_SLIDEWIN (BRLAPI_KEY_CMD(0) + 35)
 /** set skipping of lines with identical content on/off */
 #define BRLAPI_KEY_CMD_SKPIDLNS (BRLAPI_KEY_CMD(0) + 36)
-/** set skipping of blank windows on/off */
+/** set skipping of blank braille windows on/off */
 #define BRLAPI_KEY_CMD_SKPBLNKWINS (BRLAPI_KEY_CMD(0) + 37)
-/** set cursor visibility on/off */
+/** set screen cursor visibility on/off */
 #define BRLAPI_KEY_CMD_CSRVIS (BRLAPI_KEY_CMD(0) + 38)
-/** set hidden cursor on/off */
+/** set hidden screen cursor on/off */
 #define BRLAPI_KEY_CMD_CSRHIDE (BRLAPI_KEY_CMD(0) + 39)
-/** set cursor tracking on/off */
+/** set track screen cursor on/off */
 #define BRLAPI_KEY_CMD_CSRTRK (BRLAPI_KEY_CMD(0) + 40)
-/** set cursor style block/underline */
+/** set screen cursor style block/underline */
 #define BRLAPI_KEY_CMD_CSRSIZE (BRLAPI_KEY_CMD(0) + 41)
-/** set cursor blinking on/off */
+/** set screen cursor blinking on/off */
 #define BRLAPI_KEY_CMD_CSRBLINK (BRLAPI_KEY_CMD(0) + 42)
 /** set attribute underlining on/off */
 #define BRLAPI_KEY_CMD_ATTRVIS (BRLAPI_KEY_CMD(0) + 43)
@@ -140,13 +140,13 @@ extern "C" {
 #define BRLAPI_KEY_CMD_PREFSAVE (BRLAPI_KEY_CMD(0) + 53)
 /** restore preferences from disk */
 #define BRLAPI_KEY_CMD_PREFLOAD (BRLAPI_KEY_CMD(0) + 54)
-/** go to first item */
+/** go up to first item */
 #define BRLAPI_KEY_CMD_MENU_FIRST_ITEM (BRLAPI_KEY_CMD(0) + 55)
-/** go to last item */
+/** go down to last item */
 #define BRLAPI_KEY_CMD_MENU_LAST_ITEM (BRLAPI_KEY_CMD(0) + 56)
-/** go to previous item */
+/** go up to previous item */
 #define BRLAPI_KEY_CMD_MENU_PREV_ITEM (BRLAPI_KEY_CMD(0) + 57)
-/** go to next item */
+/** go down to next item */
 #define BRLAPI_KEY_CMD_MENU_NEXT_ITEM (BRLAPI_KEY_CMD(0) + 58)
 /** select previous choice */
 #define BRLAPI_KEY_CMD_MENU_PREV_SETTING (BRLAPI_KEY_CMD(0) + 59)
@@ -154,7 +154,7 @@ extern "C" {
 #define BRLAPI_KEY_CMD_MENU_NEXT_SETTING (BRLAPI_KEY_CMD(0) + 60)
 /** stop speaking */
 #define BRLAPI_KEY_CMD_MUTE (BRLAPI_KEY_CMD(0) + 61)
-/** go to current speech position */
+/** go to current speaking position */
 #define BRLAPI_KEY_CMD_SPKHOME (BRLAPI_KEY_CMD(0) + 62)
 /** speak current line */
 #define BRLAPI_KEY_CMD_SAY_LINE (BRLAPI_KEY_CMD(0) + 63)
@@ -162,21 +162,21 @@ extern "C" {
 #define BRLAPI_KEY_CMD_SAY_ABOVE (BRLAPI_KEY_CMD(0) + 64)
 /** speak from current line through bottom of screen */
 #define BRLAPI_KEY_CMD_SAY_BELOW (BRLAPI_KEY_CMD(0) + 65)
-/** decrease speech rate */
+/** decrease speaking rate */
 #define BRLAPI_KEY_CMD_SAY_SLOWER (BRLAPI_KEY_CMD(0) + 66)
-/** increase speech rate */
+/** increase speaking rate */
 #define BRLAPI_KEY_CMD_SAY_FASTER (BRLAPI_KEY_CMD(0) + 67)
-/** decrease speech volume */
+/** decrease speaking volume */
 #define BRLAPI_KEY_CMD_SAY_SOFTER (BRLAPI_KEY_CMD(0) + 68)
-/** increase speech volume */
+/** increase speaking volume */
 #define BRLAPI_KEY_CMD_SAY_LOUDER (BRLAPI_KEY_CMD(0) + 69)
-/** switch to previous virtual terminal */
+/** switch to the previous virtual terminal */
 #define BRLAPI_KEY_CMD_SWITCHVT_PREV (BRLAPI_KEY_CMD(0) + 70)
-/** switch to next virtual terminal */
+/** switch to the next virtual terminal */
 #define BRLAPI_KEY_CMD_SWITCHVT_NEXT (BRLAPI_KEY_CMD(0) + 71)
-/** bring cursor to line */
+/** bring screen cursor to current line */
 #define BRLAPI_KEY_CMD_CSRJMP_VERT (BRLAPI_KEY_CMD(0) + 72)
-/** insert clipboard text at cursor */
+/** insert clipboard text after screen cursor */
 #define BRLAPI_KEY_CMD_PASTE (BRLAPI_KEY_CMD(0) + 73)
 /** restart braille driver */
 #define BRLAPI_KEY_CMD_RESTARTBRL (BRLAPI_KEY_CMD(0) + 74)
@@ -184,15 +184,15 @@ extern "C" {
 #define BRLAPI_KEY_CMD_RESTARTSPEECH (BRLAPI_KEY_CMD(0) + 75)
 /** braille display temporarily unavailable */
 #define BRLAPI_KEY_CMD_OFFLINE (BRLAPI_KEY_CMD(0) + 76)
-/** set shift modifier of next typed character or emulated key on/off */
+/** cycle the Shift sticky input modifier (next, on, off) */
 #define BRLAPI_KEY_CMD_SHIFT (BRLAPI_KEY_CMD(0) + 77)
-/** set upper modifier of next typed character or emulated key on/off */
+/** cycle the Upper sticky input modifier (next, on, off) */
 #define BRLAPI_KEY_CMD_UPPER (BRLAPI_KEY_CMD(0) + 78)
-/** set control modifier of next typed character or emulated key on/off */
+/** cycle the Control sticky input modifier (next, on, off) */
 #define BRLAPI_KEY_CMD_CONTROL (BRLAPI_KEY_CMD(0) + 79)
-/** set meta modifier of next typed character or emulated key on/off */
+/** cycle the Meta (Left Alt) sticky input modifier (next, on, off) */
 #define BRLAPI_KEY_CMD_META (BRLAPI_KEY_CMD(0) + 80)
-/** show the current date and time */
+/** show current date and time */
 #define BRLAPI_KEY_CMD_TIME (BRLAPI_KEY_CMD(0) + 81)
 /** go to previous menu level */
 #define BRLAPI_KEY_CMD_MENU_PREV_LEVEL (BRLAPI_KEY_CMD(0) + 82)
@@ -238,11 +238,11 @@ extern "C" {
 #define BRLAPI_KEY_CMD_DESC_CURR_CHAR (BRLAPI_KEY_CMD(0) + 102)
 /** spell current word */
 #define BRLAPI_KEY_CMD_SPELL_CURR_WORD (BRLAPI_KEY_CMD(0) + 103)
-/** bring cursor to speech location */
+/** bring screen cursor to speech cursor */
 #define BRLAPI_KEY_CMD_ROUTE_CURR_LOCN (BRLAPI_KEY_CMD(0) + 104)
-/** speak speech location */
+/** speak speech cursor location */
 #define BRLAPI_KEY_CMD_SPEAK_CURR_LOCN (BRLAPI_KEY_CMD(0) + 105)
-/** set speech location visibility on/off */
+/** set speech cursor visibility on/off */
 #define BRLAPI_KEY_CMD_SHOW_CURR_LOCN (BRLAPI_KEY_CMD(0) + 106)
 /** save clipboard to disk */
 #define BRLAPI_KEY_CMD_CLIP_SAVE (BRLAPI_KEY_CMD(0) + 107)
@@ -252,15 +252,35 @@ extern "C" {
 #define BRLAPI_KEY_CMD_BRLUCDOTS (BRLAPI_KEY_CMD(0) + 109)
 /** set braille keyboard enabled/disabled */
 #define BRLAPI_KEY_CMD_BRLKBD (BRLAPI_KEY_CMD(0) + 110)
-/** enable feature */
-#define BRLAPI_KEY_FLG_TOGGLE_ON BRLAPI_KEY_FLG(0X0100)
-/** disable feature */
-#define BRLAPI_KEY_FLG_TOGGLE_OFF BRLAPI_KEY_FLG(0X0200)
-/** mask for all toggle flags */
-#define BRLAPI_KEY_FLG_TOGGLE_MASK (BRLAPI_KEY_FLG_TOGGLE_ON | BRLAPI_KEY_FLG_TOGGLE_OFF)
-/** bring cursor into window after function */
-#define BRLAPI_KEY_FLG_MOTION_ROUTE BRLAPI_KEY_FLG(0X0400)
-/** bring cursor to character */
+/** clear all sticky input modifiers */
+#define BRLAPI_KEY_CMD_UNSTICK (BRLAPI_KEY_CMD(0) + 111)
+/** cycle the AltGr (Right Alt) sticky input modifier (next, on, off) */
+#define BRLAPI_KEY_CMD_ALTGR (BRLAPI_KEY_CMD(0) + 112)
+/** cycle the GUI (Windows) sticky input modifier (next, on, off) */
+#define BRLAPI_KEY_CMD_GUI (BRLAPI_KEY_CMD(0) + 113)
+/** stop the braille driver */
+#define BRLAPI_KEY_CMD_BRL_STOP (BRLAPI_KEY_CMD(0) + 114)
+/** start the braille driver */
+#define BRLAPI_KEY_CMD_BRL_START (BRLAPI_KEY_CMD(0) + 115)
+/** stop the speech driver */
+#define BRLAPI_KEY_CMD_SPK_STOP (BRLAPI_KEY_CMD(0) + 116)
+/** start the speech driver */
+#define BRLAPI_KEY_CMD_SPK_START (BRLAPI_KEY_CMD(0) + 117)
+/** stop the screen driver */
+#define BRLAPI_KEY_CMD_SCR_STOP (BRLAPI_KEY_CMD(0) + 118)
+/** start the screen driver */
+#define BRLAPI_KEY_CMD_SCR_START (BRLAPI_KEY_CMD(0) + 119)
+/** bind to the previous virtual terminal */
+#define BRLAPI_KEY_CMD_SELECTVT_PREV (BRLAPI_KEY_CMD(0) + 120)
+/** bind to the next virtual terminal */
+#define BRLAPI_KEY_CMD_SELECTVT_NEXT (BRLAPI_KEY_CMD(0) + 121)
+/** go backward to nearest non-blank braille window */
+#define BRLAPI_KEY_CMD_PRNBWIN (BRLAPI_KEY_CMD(0) + 122)
+/** go forward to nearest non-blank braille window */
+#define BRLAPI_KEY_CMD_NXNBWIN (BRLAPI_KEY_CMD(0) + 123)
+/** set touch navigation on/off */
+#define BRLAPI_KEY_CMD_TOUCH_NAV (BRLAPI_KEY_CMD(0) + 124)
+/** bring screen cursor to character */
 #define BRLAPI_KEY_CMD_ROUTE BRLAPI_KEY_CMD(1)
 /** start new clipboard at character */
 #define BRLAPI_KEY_CMD_CLIP_NEW BRLAPI_KEY_CMD(2)
@@ -278,7 +298,7 @@ extern "C" {
 #define BRLAPI_KEY_CMD_COPY_LINE BRLAPI_KEY_CMD(5)
 /** deprecated definition of COPY_LINE - linear copy to character */
 #define BRLAPI_KEY_CMD_CUTLINE BRLAPI_KEY_CMD(5)
-/** switch to virtual terminal */
+/** switch to a specific virtual terminal */
 #define BRLAPI_KEY_CMD_SWITCHVT BRLAPI_KEY_CMD(6)
 /** go up to nearest line with less indent than character */
 #define BRLAPI_KEY_CMD_PRINDENT BRLAPI_KEY_CMD(7)
@@ -286,11 +306,11 @@ extern "C" {
 #define BRLAPI_KEY_CMD_NXINDENT BRLAPI_KEY_CMD(8)
 /** describe character */
 #define BRLAPI_KEY_CMD_DESCCHAR BRLAPI_KEY_CMD(9)
-/** place left end of window at character */
+/** place left end of braille window at character */
 #define BRLAPI_KEY_CMD_SETLEFT BRLAPI_KEY_CMD(10)
-/** remember current window position */
+/** remember current braille window position */
 #define BRLAPI_KEY_CMD_SETMARK BRLAPI_KEY_CMD(11)
-/** go to remembered window position */
+/** go to remembered braille window position */
 #define BRLAPI_KEY_CMD_GOTOMARK BRLAPI_KEY_CMD(12)
 /** go to selected line */
 #define BRLAPI_KEY_CMD_GOTOLINE BRLAPI_KEY_CMD(13)
@@ -306,19 +326,23 @@ extern "C" {
 #define BRLAPI_KEY_CMD_CLIP_APPEND BRLAPI_KEY_CMD(17)
 /** deprecated definition of CLIP_APPEND - append characters to clipboard */
 #define BRLAPI_KEY_CMD_APNDCHARS BRLAPI_KEY_CMD(17)
-/** insert clipboard history entry at cursor */
+/** insert clipboard history entry after screen cursor */
 #define BRLAPI_KEY_CMD_PASTE_HISTORY BRLAPI_KEY_CMD(18)
-/** set the text table */
+/** set text table */
 #define BRLAPI_KEY_CMD_SET_TEXT_TABLE BRLAPI_KEY_CMD(19)
-/** set the attributes table */
+/** set attributes table */
 #define BRLAPI_KEY_CMD_SET_ATTRIBUTES_TABLE BRLAPI_KEY_CMD(20)
-/** set the contraction table */
+/** set contraction table */
 #define BRLAPI_KEY_CMD_SET_CONTRACTION_TABLE BRLAPI_KEY_CMD(21)
-/** set the keyboard table */
+/** set keyboard table */
 #define BRLAPI_KEY_CMD_SET_KEYBOARD_TABLE BRLAPI_KEY_CMD(22)
-/** set the language profile */
+/** set language profile */
 #define BRLAPI_KEY_CMD_SET_LANGUAGE_PROFILE BRLAPI_KEY_CMD(23)
-/** type braille character */
+/** bind to a specific virtual terminal */
+#define BRLAPI_KEY_CMD_SELECTVT BRLAPI_KEY_CMD(30)
+/** render an alert */
+#define BRLAPI_KEY_CMD_ALERT BRLAPI_KEY_CMD(31)
+/** type braille dots */
 #define BRLAPI_KEY_CMD_PASSDOTS BRLAPI_KEY_CMD(34)
 /** AT (set 2) keyboard scan code */
 #define BRLAPI_KEY_CMD_PASSAT BRLAPI_KEY_CMD(35)
@@ -329,19 +353,31 @@ extern "C" {
 /** switch to command context */
 #define BRLAPI_KEY_CMD_CONTEXT BRLAPI_KEY_CMD(38)
 /** current reading location */
-#define BRLAPI_KEY_CMD_TOUCH BRLAPI_KEY_CMD(39)
+#define BRLAPI_KEY_CMD_TOUCH_AT BRLAPI_KEY_CMD(39)
+/** enable feature */
+#define BRLAPI_KEY_FLG_TOGGLE_ON BRLAPI_KEY_FLG(0X0100)
+/** disable feature */
+#define BRLAPI_KEY_FLG_TOGGLE_OFF BRLAPI_KEY_FLG(0X0200)
+/** mask for all toggle flags */
+#define BRLAPI_KEY_FLG_TOGGLE_MASK (BRLAPI_KEY_FLG_TOGGLE_ON | BRLAPI_KEY_FLG_TOGGLE_OFF)
+/** bring screen cursor into braille window after function */
+#define BRLAPI_KEY_FLG_MOTION_ROUTE BRLAPI_KEY_FLG(0X0400)
 /** scale arg=0X00-0XFF to screen height */
-#define BRLAPI_KEY_FLG_LINE_SCALED BRLAPI_KEY_FLG(0X0100)
+#define BRLAPI_KEY_FLG_MOTION_SCALED BRLAPI_KEY_FLG(0X0800)
 /** go to beginning of line */
-#define BRLAPI_KEY_FLG_LINE_TOLEFT BRLAPI_KEY_FLG(0X0200)
+#define BRLAPI_KEY_FLG_MOTION_TOLEFT BRLAPI_KEY_FLG(0X1000)
 /** shift key pressed */
 #define BRLAPI_KEY_FLG_SHIFT BRLAPI_KEY_FLG(0X01)
 /** convert to uppercase */
 #define BRLAPI_KEY_FLG_UPPER BRLAPI_KEY_FLG(0X02)
 /** control key pressed */
 #define BRLAPI_KEY_FLG_CONTROL BRLAPI_KEY_FLG(0X04)
-/** meta key pressed */
+/** meta (left alt) key pressed */
 #define BRLAPI_KEY_FLG_META BRLAPI_KEY_FLG(0X08)
+/** altgr (right alt) key pressed */
+#define BRLAPI_KEY_FLG_ALTGR BRLAPI_KEY_FLG(0X10)
+/** gui (windows) key pressed */
+#define BRLAPI_KEY_FLG_GUI BRLAPI_KEY_FLG(0X20)
 /** it is a release scan code */
 #define BRLAPI_KEY_FLG_KBD_RELEASE BRLAPI_KEY_FLG(0X0100)
 /** it is an emulation 0 scan code */
@@ -364,7 +400,7 @@ extern "C" {
 #define BRLAPI_DOT7 64
 /** lower-right dot of computer braille cell */
 #define BRLAPI_DOT8 128
-/** space key pressed */
+/** chord (space bar on braille keyboard) */
 #define BRLAPI_DOTC 256
 
 /** Helper macro to easily produce braille patterns */
